@@ -7,7 +7,7 @@ from mygrad.math.consts import *
 from mygrad.math.exp_log.funcs import *
 from mygrad.math.hyperbolic_trig.funcs import *
 from mygrad.math.misc.funcs import *
-from mygrad.math.nondifferentiable import argmax, argmin
+from mygrad.math.nondifferentiable import any, argmax, argmin
 from mygrad.math.sequential.funcs import *
 from mygrad.math.sequential.funcs import max, min
 from mygrad.math.trigonometric.funcs import *
@@ -16,6 +16,7 @@ from mygrad.tensor_creation.funcs import *
 from mygrad.tensor_manip.array_shape.funcs import *
 from mygrad.tensor_manip.tiling.funcs import *
 from mygrad.tensor_manip.transpose_like.funcs import *
+from . import random
 
 from ._version import get_versions
 
@@ -41,5 +42,6 @@ for attr in (
     squeeze,
     ravel,
     matmul,
+    any,
 ):
     setattr(Tensor, attr.__name__, attr)
